@@ -18,21 +18,15 @@ Instantiate a activity proxy with its key, e.g. ``("foo", "bar")``:
 
 Properties:
 
-* ``categories``
 * ``code``
 * ``database``
-* ``location``
-* ``name``
-* ``unit``
-
-``activity.exchanges`` returns a list of :ref:`exchange` objects.
+* ``exchanges`` (returns a list of :ref:`exchange` objects.)
 
 See also the descriptions of each method below.
 
     """
     def __init__(self, key):
         self.key = key
-        self.raw = self._load()
 
     # Magic methods to make Activity have the same behavior in dictionaries
     # as the normal ("foo", "bar") key
@@ -64,9 +58,24 @@ See also the descriptions of each method below.
         else:
             return self.raw[key]
 
+    def __setitem__(self, key, value):
+        raise AttributeError("Activity proxies are read-only.")
+
     def __contains__(self, key):
         return key in self.raw
 
+    def __getattr__(self, attr):
+        attr = unicode(attr)
+        if attr in self:
+            return self.raw[attr]
+        else:
+            return None
+
+    @property
+    def exchanges(self):
+        from bw2simple.exchange import Exchanges
+        return Exchanges(self.raw.get(u'exchanges', []), self)
+
     @property
     def database(self):
         return self.key[0]
@@ -75,31 +84,10 @@ See also the descriptions of each method below.
     def code(self):
         return self.key[1]
 
-    @property
-    def categories(self):
-        return self.raw.get('categories', [])
-
-    @property
-    def location(self):
-        return self.raw.get('location', [])
-
-    @property
-    def name(self):
-        return self.raw.get('name', [])
-
-    @property
-    def unit(self):
-        return self.raw.get('unit', [])
-
-    @property
-    def exchanges(self):
-        from .exchange import Exchange
-        return [Exchange(exc, self) for exc in self.raw.get('exchanges', [])]
-
     def open_in_webbrowser(self):
         """Open this activity in the web UI.
 
-        Requires `bw2-web.py` to be running."""
+        Requires `bw2-web` to be running."""
         open_activity_in_webbrowser(self)
 
     # TODO: Complete
@@ -119,6 +107,8 @@ See also the descriptions of each method below.
         return lca
 
     # Methods not normally needed in public API
-
-    def _load(self):
-        return Database(self.key[0]).load()[self]
+    @property
+    def raw(self):
+        if not hasattr(self, "_raw"):
+            self._raw = Database(self.key[0]).load()[self]
+        return self._raw
